@@ -523,4 +523,46 @@ class MagicFormulaStrategy:
                 message += 'LTP: ' + str(round(stock['CMP'], 2)) + '\n'
                 message += 'Quantity: ' + str(round(stock['Quantity'], 2)) + '\n\n'
             return message
+        return data
+    
+class IncreasedHoldings:
+    
+    def screener(self, formatMessage = True):
+        url = 'https://www.screener.in/screens/452854/ChangeInHoldings/'
+        obj = ScreenerData(url)
+        data = obj.get()
+        data.reset_index( inplace = True, drop = True)
+
+        # Strategy
+        amount_per_stock = 10000
+        data['Quantity'] = round(amount_per_stock/data['CMP'],0)
+        
+        if formatMessage:
+            message = '<b>Increase DII & FII holdings</b>\nInvest: 10K per ticker\n\n'
+            for stock in data.to_dict(orient = 'record'):
+                message += '<b>' + stock['Name'] + '</b>\n'
+                message += 'LTP: ' + str(round(stock['CMP'], 2)) + '\n'
+                message += 'Quantity: ' + str(round(stock['Quantity'], 2)) + '\n\n'
+            return message
+        return data
+    
+class GrowthPortfolio:
+    
+    def screener(self, formatMessage = True):
+        url = 'https://www.screener.in/screens/452860/GrowthCompanies/'
+        obj = ScreenerData(url)
+        data = obj.get()
+        data.reset_index( inplace = True, drop = True)
+
+        # Strategy
+        amount_per_stock = 10000
+        data['Quantity'] = round(amount_per_stock/data['CMP'],0)
+        
+        if formatMessage:
+            message = '<b>Portfolio of Growers</b>\nInvest: 10K per ticker\n\n'
+            for stock in data.to_dict(orient = 'record'):
+                message += '<b>' + stock['Name'] + '</b>\n'
+                message += 'LTP: ' + str(round(stock['CMP'], 2)) + '\n'
+                message += 'Quantity: ' + str(round(stock['Quantity'], 2)) + '\n\n'
+            return message
         return data
\ No newline at end of file
